@@ -17,11 +17,11 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-import logging
 from typing import Any, cast
 
 from gi.repository import GObject
 
+from refine.logger import logger
 from refine.widgets.toggle_row import ToggleRow
 
 
@@ -34,15 +34,15 @@ class StringRow(ToggleRow):
 
     def _settings_changed(self, *_args: Any) -> None:
         flag = self.get_string()
-        is_setting_active = cast(str, self.value) in flag
+        is_setting_active = cast("str", self.value) in flag
 
-        if not self.active == is_setting_active:
+        if self.active != is_setting_active:
             self.emit("inconsistent")
 
     def _inconsistent_set(self, *_args: Any) -> None:
         self.handler_block_by_func(self.active_set)  # type: ignore [no-untyped-call]
         flag = self.get_string()
-        self.active = cast(str, self.value) in flag
+        self.active = cast("str", self.value) in flag
         self.value_set(flag)
         self.handler_unblock_by_func(self.active_set)  # type: ignore [no-untyped-call]
 
@@ -56,7 +56,7 @@ class StringRow(ToggleRow):
 
     def do_setup(self) -> None:
         super().do_setup()
-        self.active = cast(str, self.value) in self.get_string()
+        self.active = cast("str", self.value) in self.get_string()
         self.connect("notify::active", self.active_set)
         self.connect("inconsistent", self._inconsistent_set)
         self.settings.connect("changed", self._settings_changed)
@@ -64,4 +64,4 @@ class StringRow(ToggleRow):
     @GObject.Signal
     def inconsistent(self) -> None:
         """Log inconsistency signal."""
-        logging.info(f"{self.__class__.__name__}::inconsistent signal emitted")
+        logger.info(f"{self.__class__.__name__}::inconsistent signal emitted")
